@@ -1,14 +1,17 @@
-import click
+import glob
 import json
 import os
-import glob
+import traceback
+
+import click
 from junitparser import JUnitXml, TestSuite
 
 from .case_event import CaseEvent
-from ...utils.http_client import LaunchableClient
-from ...utils.gzipgen import compress
-from ...utils.token import parse_token
+from ...testpath import TestPathComponent
 from ...utils.env_keys import REPORT_ERROR_KEY
+from ...utils.gzipgen import compress
+from ...utils.http_client import LaunchableClient
+from ...utils.token import parse_token
 
 
 @click.group()
@@ -54,6 +57,12 @@ def tests(context, base_path, session_id: str):
             self.reports = []
             self.path_builder = CaseEvent.default_path_builder(base_path)
 
+        def make_file_path_component(self, filepath) ->  TestPathComponent:
+            """Create a single TestPathComponent from the given file path"""
+            if base_path:
+                filepath = os.path.relpath(filepath, start=base_path)
+            return {"type": "file", "name": filepath}
+
         def report(self, junit_report_file: str):
             """Add one report file by its path name"""
             self.reports.append(junit_report_file)
@@ -72,7 +81,7 @@ def tests(context, base_path, session_id: str):
 
             # generator that creates the payload incrementally
             def payload():
-                yield '{"events":['
+                yield '{"events": ['
                 first = True        # used to control ',' in printing
 
                 for p in self.reports:
@@ -128,6 +137,6 @@ def tests(context, base_path, session_id: str):
                 if os.getenv(REPORT_ERROR_KEY):
                     raise e
                 else:
-                    print(e)
+                    traceback.print_exc()
 
     context.obj = RecordTests()
